@@ -6,66 +6,74 @@ Created on Sat Oct 24 14:34:59 2020
 @author: Martín Carlos Araya <martinaraya@gmail.com>
 """
 
-__version__ = '0.4.0'
-__release__ = 20220920
-__all__ = ['unit']
-
-from .errors import WrongUnitsError, WrongValueError, NoConversionFoundError
-from .operations import unitProduct, unitDivision, unitBasePower
-from .convert import converter, convertible
+__version__ = '0.4.9'
+__release__ = 20221231
+__all__ = ['Unit']
 
+from unyts.errors import WrongUnitsError, WrongValueError, NoConversionFoundError
+from unyts.operations import unit_product, unit_division, unit_base_power
+from unyts.converter import convert, convertible
 import numpy as np
-from pandas import Series, DataFrame
 from numbers import Number
+from numpy import ndarray
+from typing import Union
 
-arraylike = [np.ndarray]
 try:
     from pandas import Series, DataFrame
-    arraylike += [Series, DataFrame]
-except:
-    pass
-arraylike = tuple(arraylike)
+    array_like = tuple([ndarray, Series, DataFrame])
+    numeric = Union[int, float, complex, ndarray, Series, DataFrame]
+except ModuleNotFoundError:
+    array_like = tuple([ndarray])
+    numeric = Union[int, float, complex, ndarray]
+number = Union[int, float, complex]
 
 
-class unit(object):
+class Unit(object):
     """
     A class to cope with values associated to units, its arithmetic and logic
     operations and conversions.
     """
 
-    def __init__(self):
+    def __init__(self, value=None, unit=None):
         self.unit = None
         self.value = None
         self.name = None
         self.kind = None
+        if value is not None and unit is not None:
+            from .units.define import units
+            u = units(value, unit)
+            self.unit = u.unit
+            self.value = u.value
+            self.name = u.name
+            self.kind = u.kind
 
-    def __call__(self):
+    def __call__(self) -> numeric:
         return self.value
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return str(self.value) + '_' + str(self.unit)
 
-    def __str__(self) :
+    def __str__(self) -> str:
         return str(self.value) + '_' + str(self.unit)
 
-    def convert(self, newunit):
-        if type(newunit) is not str:
+    def convert(self, new_unit):
+        if type(new_unit) is not str:
             try:
-                newunit = newunit.unit
-            except:
-                raise WrongUnitsError("'" + str(newunit) + "' for '" + str(self.name) + "'")
-        return self.kind(converter(self.value, self.unit, newunit), newunit)
+                new_unit = new_unit.unit
+            except AttributeError:
+                raise WrongUnitsError("'" + str(new_unit) + "' for '" + str(self.name) + "'")
+        return self.kind(convert(self.value, self.unit, new_unit), new_unit)
 
-    def to(self, newunit):
-        return self.convert(newunit)
+    def to(self, new_unit):
+        return self.convert(new_unit)
 
     def __neg__(self):
         return self.kind(self.value * -1, self.unit)
 
     def __bool__(self):
-        from .units.custom import userUnits
-        from .units.unitless import dimensionless, percentage
-        if self.kind in (dimensionless, percentage, userUnits):
+        from .units.custom import UserUnits
+        from .units.unitless import Dimensionless, Percentage
+        if self.kind in (Dimensionless, Percentage, UserUnits):
             return False
         return True
 
@@ -73,25 +81,25 @@ class unit(object):
         return self.kind(abs(self.value), self.unit)
 
     def __add__(self, other):
-        from .units.unitless import dimensionless, percentage
+        from .units.unitless import Dimensionless, Percentage
         if '.units.' in str(type(other)):
             if other.kind is self.kind:
                 if self.unit == other.unit:
                     return self.kind(self.value + other.value, self.unit)
                 elif convertible(other.unit, self.unit):
-                    return self.kind(self.value + converter(other.value, other.unit, self.unit), self.unit)
+                    return self.kind(self.value + convert(other.value, other.unit, self.unit), self.unit)
                 elif convertible(self.unit, other.unit):
-                    return self.kind(other.value + converter(self.value, self.unit, other.unit), other.unit)
+                    return self.kind(other.value + convert(self.value, self.unit, other.unit), other.unit)
                 else:
                     raise NoConversionFoundError("from '" + self.unit + "' to '" + other.unit + "'")
-            if self.kind in (dimensionless, percentage) and other.kind not in (dimensionless, percentage):
+            if self.kind in (Dimensionless, Percentage) and other.kind not in (Dimensionless, Percentage):
                 return self.kind(self.value + other.value, other.unit)
-            elif self.kind is percentage and other.kind in (dimensionless, percentage):
+            elif self.kind is Percentage and other.kind in (Dimensionless, Percentage):
                 return self.kind((self.value + other.value) * 100, self.unit)
-            elif other.kind in (dimensionless, percentage):
+            elif other.kind in (Dimensionless, Percentage):
                 return self.kind(self.value + other.value, self.unit)
             else:  # add different units
-                return (self, other)
+                return self, other
         elif type(other) is tuple:
             result, flag = [], False
             for each in other:
@@ -101,8 +109,8 @@ class unit(object):
                 else:
                     result += each
             return tuple(result) if flag else other + (self,)
-        elif self.kind is percentage:
-            return self.kind((self.value + other) * 100,self.unit)
+        elif self.kind is Percentage:
+            return self.kind((self.value + other) * 100, self.unit)
         else:
             return self.kind(self.value + other, self.unit)
 
@@ -110,32 +118,34 @@ class unit(object):
         return self.__add__(other)
 
     def __mul__(self, other):
-        from .units.unitless import dimensionless, percentage
+        from .units.unitless import Dimensionless, Percentage
         from .units.define import units
         if '.units.' in str(type(other)):
-            if self.kind in (dimensionless, percentage) and other.kind not in (dimensionless, percentage):
+            if self.kind in (Dimensionless, Percentage) and other.kind not in (Dimensionless, Percentage):
                 return other.kind(self.value * other.value, other.unit)
-            elif self.kind is percentage and other.kind in (dimensionless, percentage):
+            elif self.kind is Percentage and other.kind in (Dimensionless, Percentage):
                 return self.kind((self.value * other.value) * 100, self.unit)
-            elif other.kind in (dimensionless, percentage):
+            elif other.kind in (Dimensionless, Percentage):
                 return self.kind(self.value * other.value, self.unit)
             elif self.unit == other.unit:
-                return units(self.value * other.value, unitProduct(self.unit, other.unit))
+                return units(self.value * other.value, unit_product(self.unit, other.unit))
             elif convertible(other.unit, self.unit):
-                return units(self.value * converter(other.value, other.unit, self.unit), unitProduct(self.unit, other.unit))
+                return units(self.value * convert(other.value, other.unit, self.unit),
+                             unit_product(self.unit, other.unit))
             elif convertible(self.unit, other.unit):
-                return units(other.value * converter(self.value, self.unit, other.unit), unitProduct(other.unit, self.unit))
-            elif convertible(unitBasePower(self.unit)[0], unitBasePower(other.unit)[0]):
-                factor = converter(1, unitBasePower(other.unit)[0], unitBasePower(self.unit)[0])
-                return units(self.value * other.value * factor, unitProduct(self.unit, other.unit))
+                return units(other.value * convert(self.value, self.unit, other.unit),
+                             unit_product(other.unit, self.unit))
+            elif convertible(unit_base_power(self.unit)[0], unit_base_power(other.unit)[0]):
+                factor = convert(1, unit_base_power(other.unit)[0], unit_base_power(self.unit)[0])
+                return units(self.value * other.value * factor, unit_product(self.unit, other.unit))
             else:
-                return units(self.value * other.value, unitProduct(self.unit, other.unit))
+                return units(self.value * other.value, unit_product(self.unit, other.unit))
         elif type(other) is tuple:
             result = []
             for each in other:
                 result += [self * each]
             return tuple(result)
-        elif self.kind is percentage:
+        elif self.kind is Percentage:
             return self.kind(self.value * other * 100, self.unit)
         else:
             return self.kind(self.value * other, self.unit)
@@ -144,21 +154,21 @@ class unit(object):
         return self.__mul__(other)
 
     def __pow__(self, other):
-        from .units.unitless import dimensionless, percentage
+        from .units.unitless import Dimensionless, Percentage
         from .units.define import units
         if '.units.' in str(type(other)):
-            if self.kind in (dimensionless, percentage) and other.kind not in (dimensionless, percentage):
+            if self.kind in (Dimensionless, Percentage) and other.kind not in (Dimensionless, Percentage):
                 return other.kind(self.value ** other.value, other.unit)
-            elif self.kind is percentage and other.kind in (dimensionless, percentage):
+            elif self.kind is Percentage and other.kind in (Dimensionless, Percentage):
                 return self.kind((self.value ** other.value) * 100, self.unit)
-            elif other.kind in (dimensionless, percentage):
+            elif other.kind in (Dimensionless, Percentage):
                 return self.kind(self.value ** other.value, self.unit)
             elif self.unit == other.unit:
                 return units(self.value ** other.value, self.unit + '^' + other.unit)
             elif convertible(other.unit, self.unit):
-                return units(self.value ** converter(other.value, other.unit, self.unit), self.unit + '^' + self.unit)
-            elif convertible(unitBasePower(self.unit)[0], unitBasePower(other.unit)[0]):
-                factor = converter(1, unitBasePower(other.unit)[0], unitBasePower(self.unit)[0])
+                return units(self.value ** convert(other.value, other.unit, self.unit), self.unit + '^' + self.unit)
+            elif convertible(unit_base_power(self.unit)[0], unit_base_power(other.unit)[0]):
+                factor = convert(1, unit_base_power(other.unit)[0], unit_base_power(self.unit)[0])
                 return units(self.value ** (other.value * factor), self.unit + '^' + other.unit)
             else:
                 return units(self.value ** other.value, self.unit + '^' + other.unit)
@@ -168,49 +178,49 @@ class unit(object):
                 result += [self ** each]
             return tuple(result)
         else:
-            if self.kind is percentage:
+            if self.kind is Percentage:
                 return self.kind((self.value ** other) * 100, self.unit)
             else:
-                powunits = unitBasePower(self.unit)[1] * other
-                if powunits == 0:
-                    powunits = 'dimensionless'
-                elif powunits == 1:
-                    powunits = unitBasePower(self.unit)[0]
+                pow_units = unit_base_power(self.unit)[1] * other
+                if pow_units == 0:
+                    pow_units = 'Dimensionless'
+                elif pow_units == 1:
+                    pow_units = unit_base_power(self.unit)[0]
                 else:
-                    powunits = unitBasePower(self.unit)[0] + str(powunits)
-                return units(self.value ** other, powunits)
+                    pow_units = unit_base_power(self.unit)[0] + str(pow_units)
+                return units(self.value ** other, pow_units)
 
     def __rpow__(self, other):
-        from .units.unitless import dimensionless, percentage
+        from .units.unitless import Dimensionless, Percentage
         from .units.define import units
-        if self.kind is percentage:
-            return units((other ** self.value), 'dimensionless')
-        elif self.kind is dimensionless:
+        if self.kind is Percentage:
+            return units((other ** self.value), 'Dimensionless')
+        elif self.kind is Dimensionless:
             return units(other ** self.value, self.unit)
         else:
             raise TypeError("unsupported operand type(s) for ** or pow(): '" + str(type(other)) + "' and '" + self.name)
 
     def __sub__(self, other):
         # return self.__add__(other * -1)
-        from .units.unitless import dimensionless, percentage
+        from .units.unitless import Dimensionless, Percentage
         if '.units.' in str(type(other)):
             if other.kind is self.kind:
                 if self.unit == other.unit:
                     return self.kind(self.value - other.value, self.unit)
                 elif convertible(other.unit, self.unit):
-                    return self.kind(self.value - converter(other.value, other.unit, self.unit), self.unit)
+                    return self.kind(self.value - convert(other.value, other.unit, self.unit), self.unit)
                 elif convertible(self.unit, other.unit):
-                    return self.kind(other.value - converter(self.value, self.unit, other.unit), other.unit)
+                    return self.kind(other.value - convert(self.value, self.unit, other.unit), other.unit)
                 else:
                     raise NoConversionFoundError("from '" + self.unit + "' to '" + other.unit + "'")
-            if self.kind in (dimensionless, percentage) and other.kind not in (dimensionless, percentage):
+            if self.kind in (Dimensionless, Percentage) and other.kind not in (Dimensionless, Percentage):
                 return self.kind(self.value - other.value, other.unit)
-            elif self.kind is percentage and other.kind in (dimensionless, percentage):
+            elif self.kind is Percentage and other.kind in (Dimensionless, Percentage):
                 return self.kind((self.value - other.value) * 100, self.unit)
-            elif other.kind in (dimensionless, percentage):
+            elif other.kind in (Dimensionless, Percentage):
                 return self.kind(self.value - other.value, self.unit)
             else:  # add different units
-                return (self, other)
+                return self, other
         elif type(other) is tuple:
             result, flag = [], False
             for each in other:
@@ -220,108 +230,110 @@ class unit(object):
                 else:
                     result += each
             return tuple(result) if flag else other + (self,)
-        elif self.kind is percentage:
+        elif self.kind is Percentage:
             return self.kind((self.value - other) * 100, self.unit)
         else:
             return self.kind(self.value - other, self.unit)
 
     def __rsub__(self, other):
-        return -self + other
+        return self.__neg__() + other
 
     def __truediv__(self, other):
-        from .units.unitless import dimensionless, percentage
+        from .units.unitless import Dimensionless, Percentage
         from .units.define import units
         if '.units.' in str(type(other)):
-            if self.kind in (dimensionless, percentage) and other.kind not in (dimensionless, percentage):
+            if self.kind in (Dimensionless, Percentage) and other.kind not in (Dimensionless, Percentage):
                 return other.kind(self.value / other.value, '1/' + other.unit)
-            elif self.kind is percentage and other.kind in (dimensionless, percentage):
+            elif self.kind is Percentage and other.kind in (Dimensionless, Percentage):
                 return self.kind((self.value / other.value) * 100, self.unit)
-            elif other.kind in (dimensionless, percentage):
+            elif other.kind in (Dimensionless, Percentage):
                 return self.kind(self.value / other.value, self.unit)
             elif self.unit == other.unit:
-                return units(self.value / other.value, unitDivision(self.unit, other.unit))
+                return units(self.value / other.value, unit_division(self.unit, other.unit))
             elif convertible(other.unit, self.unit):
-                return units(self.value / converter(other.value, other.unit, self.unit), unitDivision(self.unit, other.unit))
-            elif convertible(unitBasePower(self.unit)[0], unitBasePower(other.unit)[0]):
-                factor = converter(1, unitBasePower(other.unit)[0], unitBasePower(self.unit)[0])
-                return units(self.value / (other.value * factor), unitDivision(self.unit, other.unit))
+                return units(self.value / convert(other.value, other.unit, self.unit),
+                             unit_division(self.unit, other.unit))
+            elif convertible(unit_base_power(self.unit)[0], unit_base_power(other.unit)[0]):
+                factor = convert(1, unit_base_power(other.unit)[0], unit_base_power(self.unit)[0])
+                return units(self.value / (other.value * factor), unit_division(self.unit, other.unit))
             else:
-                return units(self.value / other.value, unitDivision(self.unit, other.unit))
+                return units(self.value / other.value, unit_division(self.unit, other.unit))
         elif type(other) is tuple:
             result = []
             for each in other:
                 result += [self / each]
             return tuple(result)
-        elif self.kind is percentage:
+        elif self.kind is Percentage:
             return self.kind(self.value / other * 100, self.unit)
         else:
             return units(self.value / other, self.unit)
 
     def __rtruediv__(self, other):
         from .units.define import units
-        from .units.unitless import dimensionless, percentage
-        if self.kind is percentage:
+        from .units.unitless import Dimensionless, Percentage
+        if self.kind is Percentage:
             return units(other / self.value * 100, self.unit)
-        elif self.kind is dimensionless:
+        elif self.kind is Dimensionless:
             return units(other / self.value, self.unit)
         else:
             return units(other / self.value, self.unit + '-1')
 
     def __floordiv__(self, other):
-        from .units.unitless import dimensionless, percentage
+        from .units.unitless import Dimensionless, Percentage
         from .units.define import units
         if '.units.' in str(type(other)):
-            if self.kind in (dimensionless, percentage) and other.kind not in (dimensionless, percentage):
+            if self.kind in (Dimensionless, Percentage) and other.kind not in (Dimensionless, Percentage):
                 return other.kind(self.value // other.value, '1/' + other.unit)
-            elif self.kind is percentage and other.kind in (dimensionless, percentage):
+            elif self.kind is Percentage and other.kind in (Dimensionless, Percentage):
                 return self.kind((self.value // other.value) * 100, self.unit)
-            elif other.kind in (dimensionless, percentage):
+            elif other.kind in (Dimensionless, Percentage):
                 return self.kind(self.value // other.value, self.unit)
             elif self.unit == other.unit:
-                return units(self.value // other.value, unitDivision(self.unit, other.unit))
+                return units(self.value // other.value, unit_division(self.unit, other.unit))
             elif convertible(other.unit, self.unit):
-                return units(self.value // converter(other.value, other.unit, self.unit), unitDivision(self.unit, other.unit))
-            elif convertible(unitBasePower(self.unit)[0], unitBasePower(other.unit)[0]):
-                factor = converter(1, unitBasePower(other.unit)[0], unitBasePower(self.unit)[0])
-                return units(self.value // (other.value * factor), unitDivision(self.unit, other.unit))
+                return units(self.value // convert(other.value, other.unit, self.unit),
+                             unit_division(self.unit, other.unit))
+            elif convertible(unit_base_power(self.unit)[0], unit_base_power(other.unit)[0]):
+                factor = convert(1, unit_base_power(other.unit)[0], unit_base_power(self.unit)[0])
+                return units(self.value // (other.value * factor), unit_division(self.unit, other.unit))
             else:
-                return units(self.value // other.value, unitDivision(self.unit, other.unit))
+                return units(self.value // other.value, unit_division(self.unit, other.unit))
         elif type(other) is tuple:
             result = []
             for each in other:
                 result += [self // each]
             return tuple(result)
-        elif self.kind is percentage:
+        elif self.kind is Percentage:
             return self.kind(self.value // other * 100, self.unit)
         else:
             return self.kind(self.value // other, self.unit)
 
     def __rfloordiv__(self, other):
         from .units.define import units
-        from .units.unitless import dimensionless, percentage
-        if self.kind is percentage:
+        from .units.unitless import Dimensionless, Percentage
+        if self.kind is Percentage:
             return units(other // self.value * 100, self.unit)
-        elif self.kind is dimensionless:
+        elif self.kind is Dimensionless:
             return units(other // self.value, self.unit)
         else:
             return units(other // self.value, self.unit + '-1')
 
     def __mod__(self, other):
-        from .units.unitless import dimensionless, percentage
+        from .units.unitless import Dimensionless, Percentage
         from .units.define import units
         if '.units.' in str(type(other)):
-            if self.kind in (dimensionless, percentage) and other.kind not in (dimensionless, percentage):
+            if self.kind in (Dimensionless, Percentage) and other.kind not in (Dimensionless, Percentage):
                 return other.kind(self.value % other.value, self.unit)
-            elif self.kind is percentage and other.kind in (dimensionless, percentage):
+            elif self.kind is Percentage and other.kind in (Dimensionless, Percentage):
                 return self.kind((self.value % other.value) * 100, self.unit)
-            elif other.kind in (dimensionless, percentage):
+            elif other.kind in (Dimensionless, Percentage):
                 return self.kind(self.value % other.value, self.unit)
             elif self.unit == other.unit:
                 return units(self.value % other.value, self.unit)
             elif convertible(other.unit, self.unit):
-                return units(self.value % converter(other.value, other.unit, self.unit), self.unit)
-            elif convertible(unitBasePower(self.unit)[0], unitBasePower(other.unit)[0]):
-                factor = converter(1, unitBasePower(other.unit)[0], unitBasePower(self.unit)[0])
+                return units(self.value % convert(other.value, other.unit, self.unit), self.unit)
+            elif convertible(unit_base_power(self.unit)[0], unit_base_power(other.unit)[0]):
+                factor = convert(1, unit_base_power(other.unit)[0], unit_base_power(self.unit)[0])
                 return units(self.value % (other.value * factor), self.unit)
             else:
                 return units(self.value % other.value, self.unit)
@@ -330,39 +342,51 @@ class unit(object):
             for each in other:
                 result += [self % each]
             return tuple(result)
-        elif self.kind is percentage:
+        elif self.kind is Percentage:
             return self.kind(self.value % other * 100, self.unit)
         else:
             return self.kind(self.value % other, self.unit)
 
-    def __lt__(self, other):
+    def __lt__(self, other) -> bool:
         if type(self) == type(other):
             return self.value < other.convert(self.unit).value
         else:
             msg = "'<' not supported between instances of '" + \
-                (str(type(self))[str(type(self)).index("'")+1:len(str(type(self))) - str(type(self))[::-1].index("'")-1]).replace('__main__.','') + \
-                    "' and '" + \
-                        (str(type(other))[str(type(other)).index("'")+1:len(str(type(other))) - str(type(other))[::-1].index("'")-1]).replace('__main__.', '') + "'"
+                  (str(type(self))[
+                   str(type(self)).index("'") + 1:len(str(type(self))) - str(type(self))[::-1].index("'") - 1]).replace(
+                      '__main__.', '') + \
+                  "' and '" + \
+                  (str(type(other))[
+                   str(type(other)).index("'") + 1:len(str(type(other))) - str(type(other))[::-1].index(
+                       "'") - 1]).replace('__main__.', '') + "'"
             raise TypeError(msg)
 
-    def __le__(self, other):
+    def __le__(self, other) -> bool:
         if type(self) == type(other):
             return self.value <= other.convert(self.unit).value
-        else :
+        else:
             msg = "'<=' not supported between instances of '" + \
-                (str(type(self))[str(type(self)).index("'")+1:len(str(type(self))) - str(type(self))[::-1].index("'")-1]).replace('__main__.','') + \
-                    "' and '" + \
-                        (str(type(other))[str(type(other)).index("'")+1:len(str(type(other))) - str(type(other))[::-1].index("'")-1]).replace('__main__.','') + "'"
+                  (str(type(self))[
+                   str(type(self)).index("'") + 1:len(str(type(self))) - str(type(self))[::-1].index("'") - 1]).replace(
+                      '__main__.', '') + \
+                  "' and '" + \
+                  (str(type(other))[
+                   str(type(other)).index("'") + 1:len(str(type(other))) - str(type(other))[::-1].index(
+                       "'") - 1]).replace('__main__.', '') + "'"
             raise TypeError(msg)
 
-    def __eq__(self, other):
+    def __eq__(self, other) -> bool:
         if type(self) == type(other):
             return self.value == other.convert(self.unit).value
         else:
             msg = "'==' not supported between instances of '" + \
-                (str(type(self))[str(type(self)).index("'")+1:len(str(type(self))) - str(type(self))[::-1].index("'")-1]).replace('__main__.','') + \
-                    "' and '" + \
-                        (str(type(other))[str(type(other)).index("'")+1:len(str(type(other))) - str(type(other))[::-1].index("'")-1]).replace('__main__.','') + "'"
+                  (str(type(self))[
+                   str(type(self)).index("'") + 1:len(str(type(self))) - str(type(self))[::-1].index("'") - 1]).replace(
+                      '__main__.', '') + \
+                  "' and '" + \
+                  (str(type(other))[
+                   str(type(other)).index("'") + 1:len(str(type(other))) - str(type(other))[::-1].index(
+                       "'") - 1]).replace('__main__.', '') + "'"
             raise TypeError(msg)
 
     def __ne__(self, other):
@@ -370,34 +394,47 @@ class unit(object):
             return self.value != other.convert(self.unit).value
         else:
             msg = "'!=' not supported between instances of '" + \
-                (str(type(self))[str(type(self)).index("'")+1:len(str(type(self))) - str(type(self))[::-1].index("'")-1]).replace('__main__.','') + \
-                    "' and '" + \
-                        (str(type(other))[str(type(other)).index("'")+1:len(str(type(other))) - str(type(other))[::-1].index("'")-1]).replace('__main__.','') + "'"
+                  (str(type(self))[
+                   str(type(self)).index("'") + 1:len(str(type(self))) - str(type(self))[::-1].index("'") - 1]).replace(
+                      '__main__.', '') + \
+                  "' and '" + \
+                  (str(type(other))[
+                   str(type(other)).index("'") + 1:len(str(type(other))) - str(type(other))[::-1].index(
+                       "'") - 1]).replace('__main__.', '') + "'"
             raise TypeError(msg)
 
     def __ge__(self, other):
         if type(self) == type(other):
             return self.value >= other.convert(self.unit).value
-        else :
+        else:
             msg = "'>=' not supported between instances of '" + \
-                (str(type(self))[str(type(self)).index("'")+1:len(str(type(self))) - str(type(self))[::-1].index("'")-1]).replace('__main__.','') + \
-                    "' and '" + \
-                        (str(type(other))[str(type(other)).index("'")+1:len(str(type(other))) - str(type(other))[::-1].index("'")-1]).replace('__main__.','') + "'"
+                  (str(type(self))[
+                   str(type(self)).index("'") + 1:len(str(type(self))) - str(type(self))[::-1].index("'") - 1]).replace(
+                      '__main__.', '') + \
+                  "' and '" + \
+                  (str(type(other))[
+                   str(type(other)).index("'") + 1:len(str(type(other))) - str(type(other))[::-1].index(
+                       "'") - 1]).replace('__main__.', '') + "'"
             raise TypeError(msg)
+
     def __gt__(self, other):
         if type(self) == type(other):
             return self.value > other.convert(self.unit).value
-        else :
+        else:
             msg = "'>' not supported between instances of '" + \
-                (str(type(self))[str(type(self)).index("'")+1:len(str(type(self))) - str(type(self))[::-1].index("'")-1]).replace('__main__.','') + \
-                    "' and '" + \
-                        (str(type(other))[str(type(other)).index("'")+1:len(str(type(other))) - str(type(other))[::-1].index("'")-1]).replace('__main__.','') + "'"
+                  (str(type(self))[
+                   str(type(self)).index("'") + 1:len(str(type(self))) - str(type(self))[::-1].index("'") - 1]).replace(
+                      '__main__.', '') + \
+                  "' and '" + \
+                  (str(type(other))[
+                   str(type(other)).index("'") + 1:len(str(type(other))) - str(type(other))[::-1].index(
+                       "'") - 1]).replace('__main__.', '') + "'"
             raise TypeError(msg)
 
     def __len__(self):
         try:
             return len(self.value)
-        except:
+        except TypeError:
             return 1
 
     def __getitem__(self, item):
@@ -406,8 +443,8 @@ class unit(object):
                 raise IndexError
         else:
             raise ValueError
-        from .units.unitless import percentage
-        if self.kind is percentage:
+        from .units.unitless import Percentage
+        if self.kind is Percentage:
             return self.kind(self.value[item] * 100, self.unit)
         else:
             return self.kind(self.value[item], self.unit)
@@ -418,32 +455,32 @@ class unit(object):
         else:
             return self.value.__iter__()
 
-    def getUnit(self):
+    def get_unit(self):
         return self.unit
 
-    def getValue(self):
+    def get_value(self):
         return self.value
 
-    def checkValue(self, value):
+    def check_value(self, value):
         if type(value) in (list, tuple):
             try:
                 return np.array(value)
-            except:
+            except TypeError:
                 raise WrongValueError(str(value))
         elif isinstance(value, Number):
             return value
-        elif isinstance(value, arraylike):
-             return value
+        elif isinstance(value, array_like):
+            return value
         else:
             raise WrongValueError(str(value))
 
-    def checkUnit(self, units):
+    def check_unit(self, units):
         if type(units) is not str:
             try:
                 units = units.unit
-            except:
+            except AttributeError:
                 raise WrongUnitsError("'" + str(units) + "' for '" + str(self.name) + "'")
         if units in self.kind.classUnits:
             return units
         else:
-            raise WrongUnitsError("'" + str(units) + "' for '" + str(self.name) + "'")
\ No newline at end of file
+            raise WrongUnitsError("'" + str(units) + "' for '" + str(self.name) + "'")
